@@ -1,5 +1,5 @@
 /*	HomeBank -- Free, easy, personal accounting for everyone.
- *	Copyright (C) 1995-2017 Maxime DOYEN
+ *	Copyright (C) 1995-2018 Maxime DOYEN
  *
  *	This file is part of HomeBank.
  *
@@ -322,7 +322,7 @@ static gint csvtype[7] = {
 						}
 
 						newope->kpay = payitem->key;
-						newope->wording		 = g_strdup(str_array[4]);
+						newope->memo		 = g_strdup(str_array[4]);
 						newope->amount		 = hb_qif_parser_get_amount(str_array[5]);
 
 						/* category */
