@@ -1,5 +1,5 @@
 /*  HomeBank -- Free, easy, personal accounting for everyone.
- *  Copyright (C) 1995-2017 Maxime DOYEN
+ *  Copyright (C) 1995-2018 Maxime DOYEN
  *
  *  This file is part of HomeBank.
  *
@@ -100,6 +100,10 @@ struct ui_reptime_data
 	GtkWidget	*GR_detail;
 	GtkWidget	*LV_detail;
 
+	GtkWidget	*BT_export;
+	GtkWidget	*MI_detailtoclip;
+	GtkWidget	*MI_detailtocsv;
+
 	gulong		handler_id[MAX_REPTIME_HID];
 
 };
